<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

        <xsl:output method="html"/>
	
	<xsl:preserve-space elements="code"/>

	<xsl:template match="documentation">
		<html>
		<head>
			<title><xsl:value-of select="document('config.xml')/project/@name"/> / <xsl:value-of select="/documentation/head/title"/></title>
			<style>@import "doc.css";</style>
		</head>
		<body>
			<table width="800" align="center"><tr>
				<td class="left">
					<a href="{document('config.xml')/project/@site}"><xsl:value-of select="document('config.xml')/project/@name"/></a> / #<xsl:value-of select="/documentation/head/id"/><br/><br/>
					Версия: <xsl:value-of select="/documentation/head/date/@version"/><br/>
					Дата: <xsl:value-of select="/documentation/head/date/@year"/>.<xsl:value-of select="/documentation/head/date/@month"/>.<xsl:value-of select="/documentation/head/date/@day"/>
				</td>
				<td class="right"><xsl:apply-templates select="/documentation/head/author"/></td>
			</tr>
			<tr><td colspan="2">
				<br/><div class="center"><xsl:value-of select="/documentation/head/title"/></div><br/><br/>
				<xsl:apply-templates select="/documentation/body/s"/>
			</td></tr>
			</table>

		</body>
		</html>
	</xsl:template>

	<xsl:template match="author"><a href="mailto:{@email}" target="_blank"><xsl:value-of select="."/></a><br/></xsl:template>

	<xsl:template match="s">
		<xsl:if test="name(parent::node()[1])='s'">
			<div class="title"><xsl:value-of select="@title"/></div><br/>
			<div class="indent p"><xsl:apply-templates/></div>
			<xsl:if test="count(following-sibling::s)!=0 or count(following-sibling::p)!=0"><br/></xsl:if>
		</xsl:if>
		<xsl:if test="name(parent::node()[1])='body'">
			<div class="title"><xsl:value-of select="@title"/></div><br/>
			<div class="indent p"><xsl:apply-templates/></div>
			<xsl:if test="count(following-sibling::s)!=0 or count(following-sibling::p)!=0"><br/><br/></xsl:if>
		</xsl:if>
	</xsl:template>

	<xsl:template match="p">
		<div class="p"><xsl:apply-templates/></div>
		<xsl:if test="count(following-sibling::p)!=0 or count(following-sibling::s)!=0"><br/></xsl:if>
	</xsl:template>

	<xsl:template match="code">
		<xsl:if test="not(@src)"><pre class="code"><xsl:apply-templates/></pre></xsl:if>
		<xsl:if test="@src"><xsl:apply-templates select="document(@src)/code"/></xsl:if>
	</xsl:template>

	<xsl:template match="a">
		<xsl:if test="not(@id)"><a href="{@href}" target="_blank"><xsl:value-of select="."/></a></xsl:if>
		<xsl:if test="@id"><nobr><a href="{@id}.xml"><xsl:value-of select="."/></a></nobr></xsl:if>
	</xsl:template>
	
	<xsl:template match="img">
		<table class="indent">
			<tr><td><img src="{@src}"/></td></tr>
			<tr><td class="comment"><xsl:value-of select="@comment"/></td></tr>
		</table>
	</xsl:template>
	
	<xsl:template match="i"><i><xsl:apply-templates/></i></xsl:template>
	
	<xsl:template match="b"><b><xsl:apply-templates/></b></xsl:template>
	
<!--
	<xsl:template match="ul"><div class="indent p"><xsl:apply-templates select="li" mode="ul"/></div></xsl:template>

	<xsl:template match="ol"><div class="indent p"><xsl:apply-templates select="li" mode="ol"/></div></xsl:template>
-->
	<xsl:template match="ul"><div class="indent p"><xsl:apply-templates mode="ul"/></div></xsl:template>
	<xsl:template match="ul" mode="ol"><div class="indent p"><xsl:apply-templates mode="ul"/></div></xsl:template>
	<xsl:template match="ul" mode="ul"><div class="indent p"><xsl:apply-templates mode="ul"/></div></xsl:template>

	<xsl:template match="ol"><div class="indent p"><xsl:apply-templates mode="ol"/></div></xsl:template>
	<xsl:template match="ol" mode="ol"><div class="indent p"><xsl:apply-templates mode="ol"/></div></xsl:template>
	<xsl:template match="ol" mode="ul"><div class="indent p"><xsl:apply-templates mode="ol"/></div></xsl:template>

	<xsl:template match="li" mode="ul"><div class="p">* <xsl:apply-templates/></div></xsl:template>
	
	<xsl:template match="li" mode="ol">
		<div class="p">
			<!-- <xsl:if test="not(@value)"><xsl:value-of select="position()"/>. </xsl:if> -->
			<xsl:if test="not(@value)"><xsl:value-of select="count(preceding-sibling::li)+1"/>. </xsl:if>
			<xsl:if test="@value"><xsl:value-of select="@value"/>. </xsl:if>
			<xsl:apply-templates/>
		</div>
	</xsl:template>

	<xsl:template match="table"><table class="table indent"><xsl:apply-templates/></table></xsl:template>

	<xsl:template match="tr"><tr><xsl:apply-templates/></tr></xsl:template>
	
	<xsl:template match="td"><td class="table"><xsl:apply-templates/></td></xsl:template>
	
	<xsl:template match="todo">
		<span class="todo"><b>TODO: </b><xsl:apply-templates/></span>
	</xsl:template>

	<xsl:template match="br"><br/></xsl:template>

</xsl:stylesheet>
